@@ -34,7 +34,7 @@ var languageNames = {
 "it": "Italian",
 "ja": "Japanese",
 "ka": "Georgian",
-"km": "Khmer",
+"km": "Ḥemer",
 "ko": "Korean",
 "lo": "Lao",
 "lt": "Lithuanian",
